%define daemon_user monitor
%if 0%{?suse_version}
%define httpconfdir apache2/conf.d
%define daemon_group www
%else
%define httpconfdir httpd/conf.d
%define daemon_group apache
%endif

%{?dgroup:%define daemon_group %{dgroup}}

Summary: pnp4nagios (PNP is not PerfParse) for op5monitor
Name: monitor-pnp
Version: %{op5version}
Release: %{op5release}%{?dist}
Group: op5/Monitor
License: GPLv2 and MIT and BSD
Prefix: /opt/monitor
URL: http://www.op5.com
Source0: %name-%version.tar.gz
Requires: monitor >= 4.0, rrdtool >= 1.4.4.1, perl-rrdtool >= 1.4.4.1
Requires: sed >= 4.0.9
Requires: op5-monitor-supported-webserver
Requires: monitor-ninja
BuildRequires: rrdtool >= 1.4.4.2
BuildRequires: perl-rrdtool >= 1.4.4.2
BuildRequires: autoconf, gcc
BuildRequires: perl
# FIXME: must add Requires of monitor version where the CGIs are patched.
BuildRoot: %{_tmppath}/%{name}-%{version}
%if 0%{?suse_version}
# SLES-specific stuff
Requires: php53-mbstring
%else
# Common RHEL stuff
Requires: php-mbstring
%if 0%{?rhel} >= 6
# RHEL6-specific stuff
%else
# RHEL5-specific stuff
%endif
%endif

%description
PNP is an addon to Nagios which analyzes performance data provided by
plugins and stores them automatically into RRD-databases.

%prep
%setup -q

%build
autoconf
CFLAGS="%optflags" ./configure \
	--prefix=%prefix \
	--sysconfdir=%prefix/etc/pnp \
	--datarootdir=%prefix/op5/pnp \
	--libexecdir=%prefix/op5/pnp \
	--mandir=%{_mandir} \
	--with-nagios-user=$(id -un) \
	--with-nagios-group=$(id -gn) \
	--with-kohana_system=%prefix/op5/ninja/system \
	--with-perfdata-spool-dir=/opt/monitor/var/spool/perfdata \
	--with-perfdata-dir=/opt/monitor/op5/pnp/perfdata

# should we change PACKAGE_NAME, PACKAGE_TARNAME from "pnp"?

%__make KOHANA=no all


%install
rm -rf %buildroot

mkdir -p %buildroot
make KOHANA=no DESTDIR=%buildroot install
mkdir -p %buildroot%prefix/op5/pnp/modules
install -m 755 scripts/pdppd.pl %buildroot%prefix/op5/pnp/

for i in npcd.cfg process_perfdata.cfg rra.cfg
do
	test -f op5build/$i && src=op5build/$i || src=sample-config/pnp/$i-sample
	cp "$src" %buildroot/%prefix/etc/pnp/$i
done

cp op5build/background.pdf %buildroot%prefix/etc/pnp
cp op5build/pnp_nagios.cfg %buildroot/%prefix/op5/pnp/pnp_nagios.cfg
cp op5build/pnpcommands.cfg %buildroot/%prefix/op5/pnp/pnpcommands.cfg
mkdir -p %buildroot/etc/init.d
install -m755 scripts/rc.npcd %buildroot/etc/init.d/npcd
install -Dm 644 op5build/pnp_icon.png \
	%buildroot%prefix/share/images/logos/pnp_icon.png

# remove the broker module and everything else that ends up in lib
rm -rf %buildroot%prefix/lib

# now copy the module to its proper place
cp src/npcdmod.o %buildroot%prefix/op5/pnp


# remove the install.php file. we know things will work
rm -f %buildroot%prefix/op5/pnp/install.php

# FIXME: get rid of this hack when pnp is properly patched to install
#        with a silently failing chown after install instead of
#        using INSTALL_OPTS
sed -i \
	   -e 's/\(NpcdUser=\).*/\1%{daemon_user}/' \
	   -e 's/\(NpcdGroup=\).*/\1%{daemon_group}/' \
	   %buildroot/etc/init.d/npcd

# FIXME: get rid of this hack too when (see above)
sed -i \
	   -e 's/^user = .*/user = %{daemon_user}/' \
	   -e 's/^group =.*/group = %{daemon_group}/' \
	   %buildroot%prefix/etc/pnp/npcd.cfg


# Don't display the xml icon. It's pretty useless after all
# We also set it to use rrdcached by default
sed -i \
	-e 's/\(.*show_xml_icon[^=]*=\).*/\1 0;/' \
	-e 's#\(^$conf..RRD_DAEMON_OPTS[^=]*\).*#\1= "unix:/opt/monitor/var/rrdtool/rrdcached/rrdcached.sock";#' \
	%buildroot%prefix/etc/pnp/config.php

# current pnp requires rewrite rules to work properly,
# so install them
mkdir -p %buildroot/etc/%{httpconfdir}
cp op5build/pnp.conf-httpd %buildroot/etc/%{httpconfdir}/pnp.conf

mkdir -p %buildroot%prefix/op5/nacoma/hooks/save
install -m 755 op5build/nacoma_hook.py %buildroot%prefix/op5/nacoma/hooks/save/pnp_hook.py

# create the spool directory
mkdir -p -m 775 %buildroot%prefix/var/spool/perfdata

mkdir -p -m 775 %buildroot%prefix/op5/pnp/perfdata/.trash

install -m 755 op5build/check_nrpe.cfg %buildroot%prefix/etc/pnp/check_commands/
ln -s check_load.php %buildroot%prefix/op5/pnp/templates.dist/load.php
ln -s check_users.php %buildroot%prefix/op5/pnp/templates.dist/users.php
ln -s check_disk.php %buildroot%prefix/op5/pnp/templates.dist/root_disk.php
ln -s check_disk.php %buildroot%prefix/op5/pnp/templates.dist/usr_disk.php
ln -s check_disk.php %buildroot%prefix/op5/pnp/templates.dist/var_disk.php

ln -s check_traffic.php %buildroot%prefix/op5/pnp/templates.dist/check_snmpif_traffic.php
ln -s check_iferrors.php %buildroot%prefix/op5/pnp/templates.dist/check_snmpif_errors.php
## remove some templates we don't want
# We either create a billion symlinks for all check_http* flavours, or
# we let all of them fall back to the (very nearly) identical default
# template.
rm -f %buildroot%prefix/op5/pnp/templates.dist/check_http*

%post
# make sure npcd is started at system boot
chkconfig --add npcd

if test $1 -eq 1; then
	# new install, so edit misccommands.cfg
	# Set up process-host-perfdata and process-service-perfdata commands

	if grep -q process-service-perfdata %prefix/etc/misccommands.cfg
	then
		sed -i /"# command 'process-service-perfdata'"/,/\}/d %prefix/etc/misccommands.cfg
	fi

	if grep -q process-host-perfdata %prefix/etc/misccommands.cfg
	then
		sed -i /"# command 'process-host-perfdata'"/,/\}/d %prefix/etc/misccommands.cfg
	fi

	cat %prefix/op5/pnp/pnpcommands.cfg >> %prefix/etc/misccommands.cfg
fi

# edit nagios.cfg:
# make sure we have process_performance_data activated
if grep -q process_performance_data %prefix/etc/nagios.cfg
then
	sed -i 's/process_performance_data=0/process_performance_data=1/' %prefix/etc/nagios.cfg
else
	echo process_performance_data=1 >> %prefix/etc/nagios.cfg
fi

# remove old service_perfdata_file params in nagios.cfg,
# added by an old version of the post scriptlet
sed -i '/^# service performance data .PNP.$/,/host_perfdata_file_processing_c/d' \
	%prefix/etc/nagios.cfg

# Add perfdata options to nagios.cfg unless it's already there
if ! grep -q '## PNP config start' %prefix/etc/nagios.cfg; then
	cat %prefix/op5/pnp/pnp_nagios.cfg >> %prefix/etc/nagios.cfg
fi


# make sure process_perfdata timeout is 1 second less than the
# perfdata processing interval
hpdpi=$(grep 'host_perfdata_file_processing_interval=' %prefix/etc/nagios.cfg | sed 's/[^0-9]\+//')
hpdpi=$(expr $hpdpi - 1)
test -z "$hpdpi" && hpdpi=15
sed -i "s/^TIMEOUT.*=.*/TIMEOUT = $hpdpi/" %prefix/etc/pnp/process_perfdata.cfg

/etc/init.d/npcd start || :
/etc/init.d/monitor restart || :
%if 0%{?suse_version}
/etc/init.d/apache2 restart || :
%else
/etc/init.d/httpd restart || :
%endif


%preun
if [ $1 -eq 0 ]; then
	sh /etc/init.d/npcd stop || :
fi


%files
%defattr(-,%daemon_user,%daemon_group)
/etc/init.d/npcd
%prefix/share/images/logos/pnp_icon.png
%prefix/bin/npcd
%prefix/op5/pnp
%prefix/var/spool/perfdata
%prefix/var/stats
%attr(775,%daemon_user,%daemon_group) %prefix/op5/pnp/templates
%attr(775,%daemon_user,%daemon_group) %prefix/op5/pnp/perfdata
%attr(775,%daemon_user,%daemon_group) %prefix/op5/pnp/perfdata/.trash
%attr(775,%daemon_user,%daemon_group) %prefix/etc/pnp/pages
%dir %prefix/etc/pnp
%config(noreplace) %prefix/etc/pnp/*
%attr(644,root,root) /etc/%{httpconfdir}/pnp.conf
%prefix/op5/nacoma/hooks/save/pnp_hook.py*
%doc AUTHORS ChangeLog COPYING INSTALL README THANKS
%doc %{_mandir}/man8/npcd.8.gz

%clean
rm -rf %buildroot

%changelog
* Tue Nov 9 2010 Andreas Ericsson <ae@op5.se>
- Initial specfile creation, inherited from our pnp-0.4.12.6 package
